import _extends from "reshow-runtime/es/helpers/extends";
import _objectWithoutProperties from "reshow-runtime/es/helpers/objectWithoutProperties";
import _defineProperty from "reshow-runtime/es/helpers/defineProperty";

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(source, true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(source).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

import React from 'react';
import callfunc from 'call-func';
import get from 'get-object-value';
import { build, min, mixClass, lazyInject, Item, Menu } from 'react-atomic-molecule';
var isArray = Array.isArray;

var plusOne = function plusOne(i) {
  return i + 1;
};

var getFromTo = function getFromTo(from, to) {
  return plusOne(from) + '-' + plusOne(to);
};

var keys = Object.keys;

var mergeStyle = function mergeStyle(main) {
  var style = _objectSpread({}, get(main, ['style'], {}));

  for (var _len = arguments.length, merges = new Array(_len > 1 ? _len - 1 : 0), _key = 1; _key < _len; _key++) {
    merges[_key - 1] = arguments[_key];
  }

  merges.forEach(function (m) {
    var mStyle = get(m, ['style'], {});
    keys(mStyle).forEach(function (key) {
      return style[key] = mStyle[key];
    });
  });
  return style;
};

var BasePage = function BasePage(props) {
  var onPageChange = props.onPageChange,
      component = props.component,
      className = props.className,
      children = props.children,
      style = props.style,
      url = props.url,
      rel = props.rel;
  var classes = mixClass(get(component, ['props', 'className']), className, 'item link');
  var onClick = onPageChange ? function () {
    return callfunc(onPageChange, [{
      begin: props[0],
      end: props[1],
      page: props['currentPage'],
      perPageNum: props['perPageNum']
    }]);
  } : null;
  return build(component)({
    rel: rel,
    title: getFromTo(props[0], props[1]),
    className: classes,
    href: url,
    style: style,
    onClick: onClick,
    'data-begin': props[0],
    'data-end': props[1],
    'data-page': props['currentPage'],
    'data-per-page-num': props['perPageNum']
  }, children);
};

var Page = function Page(props) {
  return React.createElement(BasePage, props, props.currentPage);
};

var Forward = function Forward(_ref) {
  var isLastPage = _ref.isLastPage,
      text = _ref.text,
      props = _objectWithoutProperties(_ref, ["isLastPage", "text"]);

  return React.createElement(BasePage, _extends({}, props, {
    rel: "next"
  }), isLastPage ? props.currentPage : text);
};

var Backward = function Backward(_ref2) {
  var text = _ref2.text,
      props = _objectWithoutProperties(_ref2, ["text"]);

  return React.createElement(BasePage, _extends({}, props, {
    rel: "prev"
  }), props.currentPage === 1 ? props.currentPage : text);
};

var Current = function Current(props) {
  return React.createElement(Item, {
    style: props.style,
    title: getFromTo(props[0], props[1]),
    className: mixClass('active', props.className)
  }, props.currentPage);
};

var FirstPage = function FirstPage(props) {
  return React.createElement(Page, props);
};

var LastPage = function LastPage(props) {
  return React.createElement(Page, props);
};

var Ellipsis = function Ellipsis(props) {
  return React.createElement(Item, {
    className: "disabled ellipsis",
    style: _objectSpread({
      minWidth: 0,
      width: 0
    }, props.style)
  }, "...");
};

var Pagination = function Pagination(pg) {
  injects = lazyInject(injects, InjectStyles);
  var linkComponent = pg.linkComponent,
      onPageChange = pg.onPageChange,
      forwardText = pg.forwardText,
      backwardText = pg.backwardText,
      ui = pg.ui,
      currentPageProps = pg.currentPageProps;
  var firstPage;
  var firstEllipsis;
  var lastPage;
  var lastEllipsis;
  var pageProps = pg.pageProps || {};
  pageProps.onPageChange = onPageChange;
  pageProps.component = linkComponent;

  var ellipsisProps = _objectSpread({}, pageProps, {
    onPageChange: null
  });

  if (pg.firstPage) {
    firstPage = React.createElement(FirstPage, _extends({}, pg.firstPage, pageProps));
    firstEllipsis = React.createElement(Ellipsis, ellipsisProps);
  }

  if (pg.lastPage) {
    lastPage = React.createElement(LastPage, _extends({}, pg.lastPage, pageProps));
    lastEllipsis = React.createElement(Ellipsis, ellipsisProps);
  }

  var pgList = pg.list;

  if (!isArray(pgList)) {
    console.error('Page list not array', pg);
  }

  return React.createElement(Menu, {
    className: "compact pagination",
    ui: ui
  }, firstPage, firstEllipsis, pgList.map(function (v, k) {
    var current = pg.currentPage;

    if (v.currentPage) {
      if (current.backward && current.backward.currentPage === v.currentPage || current.forward && current.forward.currentPage === v.currentPage) {
        return null;
      }

      return React.createElement(Page, _extends({}, pageProps, {
        key: k
      }, v));
    } else {
      var re = [];

      if (current.backward) {
        re.push(React.createElement(Backward, _extends({
          text: backwardText
        }, current.backward, pageProps)));
      }

      re.push(React.createElement(Current, _extends({
        key: k
      }, pageProps, current, currentPageProps, {
        style: mergeStyle(pageProps, currentPageProps)
      })));

      if (current.forward) {
        re.push(React.createElement(Forward, _extends({
          isLastPage: pgList.length - 2 === k
        }, current.forward, {
          text: forwardText
        }, pageProps)));
      }

      return re;
    }
  }), lastEllipsis, lastPage);
};

Pagination.defaultProps = {
  linkComponent: 'a',
  forwardText: '> Next',
  backwardText: '<'
};
export default Pagination;
var injects;
var pgCssSelector = '.pagination.ui.menu:not(.vertical) .item';
var InjectStyles = {
  hidePg: [{
    display: 'none',
    minWidth: '2rem',
    justifyContent: 'center'
  }, pgCssSelector],
  showPg: [{
    display: 'flex'
  }, [min.sm, pgCssSelector]]
};